Class: Aws::RAM::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RAM::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ram/client.rb,
sig/client.rbs
Overview
An API client for RAM. To construct a client, you need to configure a :region and :credentials.
client = Aws::RAM::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptResourceShareInvitationResponseSuccess, _AssociateResourceSharePermissionResponseSuccess, _AssociateResourceShareResponseSuccess, _CreatePermissionResponseSuccess, _CreatePermissionVersionResponseSuccess, _CreateResourceShareResponseSuccess, _DeletePermissionResponseSuccess, _DeletePermissionVersionResponseSuccess, _DeleteResourceShareResponseSuccess, _DisassociateResourceSharePermissionResponseSuccess, _DisassociateResourceShareResponseSuccess, _EnableSharingWithAwsOrganizationResponseSuccess, _GetPermissionResponseSuccess, _GetResourcePoliciesResponseSuccess, _GetResourceShareAssociationsResponseSuccess, _GetResourceShareInvitationsResponseSuccess, _GetResourceSharesResponseSuccess, _ListPendingInvitationResourcesResponseSuccess, _ListPermissionAssociationsResponseSuccess, _ListPermissionVersionsResponseSuccess, _ListPermissionsResponseSuccess, _ListPrincipalsResponseSuccess, _ListReplacePermissionAssociationsWorkResponseSuccess, _ListResourceSharePermissionsResponseSuccess, _ListResourceTypesResponseSuccess, _ListResourcesResponseSuccess, _ListSourceAssociationsResponseSuccess, _PromotePermissionCreatedFromPolicyResponseSuccess, _PromoteResourceShareCreatedFromPolicyResponseSuccess, _RejectResourceShareInvitationResponseSuccess, _ReplacePermissionAssociationsResponseSuccess, _SetDefaultPermissionVersionResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateResourceShareResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_resource_share_invitation(params = {}) ⇒ Types::AcceptResourceShareInvitationResponse
Accepts an invitation to a resource share from another Amazon Web Services account.
-
#associate_resource_share(params = {}) ⇒ Types::AssociateResourceShareResponse
Adds the specified list of principals, resources, and source constraints to a resource share.
-
#associate_resource_share_permission(params = {}) ⇒ Types::AssociateResourceSharePermissionResponse
Adds or replaces the RAM permission for a resource type included in a resource share.
-
#create_permission(params = {}) ⇒ Types::CreatePermissionResponse
Creates a customer managed permission for a specified resource type that you can attach to resource shares.
-
#create_permission_version(params = {}) ⇒ Types::CreatePermissionVersionResponse
Creates a new version of the specified customer managed permission.
-
#create_resource_share(params = {}) ⇒ Types::CreateResourceShareResponse
Creates a resource share.
-
#delete_permission(params = {}) ⇒ Types::DeletePermissionResponse
Deletes the specified customer managed permission in the Amazon Web Services Region in which you call this operation.
-
#delete_permission_version(params = {}) ⇒ Types::DeletePermissionVersionResponse
Deletes one version of a customer managed permission.
-
#delete_resource_share(params = {}) ⇒ Types::DeleteResourceShareResponse
Deletes the specified resource share.
-
#disassociate_resource_share(params = {}) ⇒ Types::DisassociateResourceShareResponse
Removes the specified principals, resources, or source constraints from participating in the specified resource share.
-
#disassociate_resource_share_permission(params = {}) ⇒ Types::DisassociateResourceSharePermissionResponse
Removes a managed permission from a resource share.
-
#enable_sharing_with_aws_organization(params = {}) ⇒ Types::EnableSharingWithAwsOrganizationResponse
Enables resource sharing within your organization in Organizations.
-
#get_permission(params = {}) ⇒ Types::GetPermissionResponse
Retrieves the contents of a managed permission in JSON format.
-
#get_resource_policies(params = {}) ⇒ Types::GetResourcePoliciesResponse
Retrieves the resource policies for the specified resources that you own and have shared.
-
#get_resource_share_associations(params = {}) ⇒ Types::GetResourceShareAssociationsResponse
Retrieves the lists of resources and principals that associated for resource shares that you own.
-
#get_resource_share_invitations(params = {}) ⇒ Types::GetResourceShareInvitationsResponse
Retrieves details about invitations that you have received for resource shares.
-
#get_resource_shares(params = {}) ⇒ Types::GetResourceSharesResponse
Retrieves details about the resource shares that you own or that are shared with you.
-
#list_pending_invitation_resources(params = {}) ⇒ Types::ListPendingInvitationResourcesResponse
Lists the resources in a resource share that is shared with you but for which the invitation is still
PENDING. -
#list_permission_associations(params = {}) ⇒ Types::ListPermissionAssociationsResponse
Lists information about the managed permission and its associations to any resource shares that use this managed permission.
-
#list_permission_versions(params = {}) ⇒ Types::ListPermissionVersionsResponse
Lists the available versions of the specified RAM permission.
-
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Retrieves a list of available RAM permissions that you can use for the supported resource types.
-
#list_principals(params = {}) ⇒ Types::ListPrincipalsResponse
Lists the principals that you are sharing resources with or that are sharing resources with you.
-
#list_replace_permission_associations_work(params = {}) ⇒ Types::ListReplacePermissionAssociationsWorkResponse
Retrieves the current status of the asynchronous tasks performed by RAM when you perform the ReplacePermissionAssociationsWork operation.
-
#list_resource_share_permissions(params = {}) ⇒ Types::ListResourceSharePermissionsResponse
Lists the RAM permissions that are associated with a resource share.
-
#list_resource_types(params = {}) ⇒ Types::ListResourceTypesResponse
Lists the resource types that can be shared by RAM.
-
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Lists the resources that you added to a resource share or the resources that are shared with you.
-
#list_source_associations(params = {}) ⇒ Types::ListSourceAssociationsResponse
Lists source associations for resource shares.
-
#promote_permission_created_from_policy(params = {}) ⇒ Types::PromotePermissionCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM automatically creates a resource share of
featureSet=CREATED_FROM_POLICYwith a managed permission that has the same IAM permissions as the original resource-based policy. -
#promote_resource_share_created_from_policy(params = {}) ⇒ Types::PromoteResourceShareCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM automatically creates a resource share of
featureSet=CREATED_FROM_POLICYwith a managed permission that has the same IAM permissions as the original resource-based policy. -
#reject_resource_share_invitation(params = {}) ⇒ Types::RejectResourceShareInvitationResponse
Rejects an invitation to a resource share from another Amazon Web Services account.
-
#replace_permission_associations(params = {}) ⇒ Types::ReplacePermissionAssociationsResponse
Updates all resource shares that use a managed permission to a different managed permission.
-
#set_default_permission_version(params = {}) ⇒ Types::SetDefaultPermissionVersionResponse
Designates the specified version number as the default version for the specified customer managed permission.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag keys and values to a resource share or managed permission.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tag key and value pairs from the specified resource share or managed permission.
-
#update_resource_share(params = {}) ⇒ Types::UpdateResourceShareResponse
Modifies some of the properties of the specified resource share.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ram/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3596 3597 3598 |
# File 'lib/aws-sdk-ram/client.rb', line 3596 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3599 3600 3601 |
# File 'lib/aws-sdk-ram/client.rb', line 3599 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_resource_share_invitation(params = {}) ⇒ Types::AcceptResourceShareInvitationResponse
Accepts an invitation to a resource share from another Amazon Web Services account. After you accept the invitation, the resources included in the resource share are available to interact with in the relevant Amazon Web Services Management Consoles and tools.
87 |
# File 'sig/client.rbs', line 87
def accept_resource_share_invitation: (
|
#associate_resource_share(params = {}) ⇒ Types::AssociateResourceShareResponse
Adds the specified list of principals, resources, and source constraints to a resource share. Principals that already have access to this resource share immediately receive access to the added resources. Newly added principals immediately receive access to the resources shared in this resource share.
99 |
# File 'sig/client.rbs', line 99
def associate_resource_share: (
|
#associate_resource_share_permission(params = {}) ⇒ Types::AssociateResourceSharePermissionResponse
Adds or replaces the RAM permission for a resource type included in a resource share. You can have exactly one permission associated with each resource type in the resource share. You can add a new RAM permission only if there are currently no resources of that resource type currently in the resource share.
114 |
# File 'sig/client.rbs', line 114
def associate_resource_share_permission: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 |
# File 'lib/aws-sdk-ram/client.rb', line 3569 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RAM') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ram' context[:gem_version] = '1.91.0' Seahorse::Client::Request.new(handlers, context) end |
#create_permission(params = {}) ⇒ Types::CreatePermissionResponse
Creates a customer managed permission for a specified resource type that you can attach to resource shares. It is created in the Amazon Web Services Region in which you call the operation.
129 |
# File 'sig/client.rbs', line 129
def create_permission: (
|
#create_permission_version(params = {}) ⇒ Types::CreatePermissionVersionResponse
Creates a new version of the specified customer managed permission. The new version is automatically set as the default version of the customer managed permission. New resource shares automatically use the default permission. Existing resource shares continue to use their original permission versions, but you can use ReplacePermissionAssociations to update them.
If the specified customer managed permission already has the maximum of 5 versions, then you must delete one of the existing versions before you can create a new one.
149 |
# File 'sig/client.rbs', line 149
def create_permission_version: (
|
#create_resource_share(params = {}) ⇒ Types::CreateResourceShareResponse
Creates a resource share. You can provide a list of the Amazon Resource Names (ARNs) for the resources that you want to share, a list of principals you want to share the resources with, the permissions to grant those principals, and optionally source constraints to enhance security for service principal sharing.
162 |
# File 'sig/client.rbs', line 162
def create_resource_share: (
|
#delete_permission(params = {}) ⇒ Types::DeletePermissionResponse
Deletes the specified customer managed permission in the Amazon Web Services Region in which you call this operation. You can delete a customer managed permission only if it isn't attached to any resource share. The operation deletes all versions associated with the customer managed permission.
189 |
# File 'sig/client.rbs', line 189
def delete_permission: (
|
#delete_permission_version(params = {}) ⇒ Types::DeletePermissionVersionResponse
Deletes one version of a customer managed permission. The version you specify must not be attached to any resource share and must not be the default version for the permission.
If a customer managed permission has the maximum of 5 versions, then you must delete at least one version before you can create another.
202 |
# File 'sig/client.rbs', line 202
def delete_permission_version: (
|
#delete_resource_share(params = {}) ⇒ Types::DeleteResourceShareResponse
Deletes the specified resource share.
This doesn't delete any of the resources that were associated with the resource share; it only stops the sharing of those resources through this resource share.
215 |
# File 'sig/client.rbs', line 215
def delete_resource_share: (
|
#disassociate_resource_share(params = {}) ⇒ Types::DisassociateResourceShareResponse
Removes the specified principals, resources, or source constraints from participating in the specified resource share.
227 |
# File 'sig/client.rbs', line 227
def disassociate_resource_share: (
|
#disassociate_resource_share_permission(params = {}) ⇒ Types::DisassociateResourceSharePermissionResponse
Removes a managed permission from a resource share. Permission changes take effect immediately. You can remove a managed permission from a resource share only if there are currently no resources of the relevant resource type currently attached to the resource share.
242 |
# File 'sig/client.rbs', line 242
def disassociate_resource_share_permission: (
|
#enable_sharing_with_aws_organization(params = {}) ⇒ Types::EnableSharingWithAwsOrganizationResponse
Enables resource sharing within your organization in Organizations.
This operation creates a service-linked role called
AWSServiceRoleForResourceAccessManager that has the IAM managed
policy named AWSResourceAccessManagerServiceRolePolicy attached. This
role permits RAM to retrieve information about the organization and
its structure. This lets you share resources with all of the accounts
in the calling account's organization by specifying the organization
ID, or all of the accounts in an organizational unit (OU) by
specifying the OU ID. Until you enable sharing within the
organization, you can specify only individual Amazon Web Services
accounts, or for supported resource types, IAM roles and users.
You must call this operation from an IAM role or user in the organization's management account.
254 |
# File 'sig/client.rbs', line 254
def enable_sharing_with_aws_organization: (
|
#get_permission(params = {}) ⇒ Types::GetPermissionResponse
Retrieves the contents of a managed permission in JSON format.
263 |
# File 'sig/client.rbs', line 263
def get_permission: (
|
#get_resource_policies(params = {}) ⇒ Types::GetResourcePoliciesResponse
Retrieves the resource policies for the specified resources that you own and have shared.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
275 |
# File 'sig/client.rbs', line 275
def get_resource_policies: (
|
#get_resource_share_associations(params = {}) ⇒ Types::GetResourceShareAssociationsResponse
Retrieves the lists of resources and principals that associated for resource shares that you own.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
289 |
# File 'sig/client.rbs', line 289
def get_resource_share_associations: (
|
#get_resource_share_invitations(params = {}) ⇒ Types::GetResourceShareInvitationsResponse
Retrieves details about invitations that you have received for resource shares.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
306 |
# File 'sig/client.rbs', line 306
def get_resource_share_invitations: (
|
#get_resource_shares(params = {}) ⇒ Types::GetResourceSharesResponse
Retrieves details about the resource shares that you own or that are shared with you.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
320 |
# File 'sig/client.rbs', line 320
def get_resource_shares: (
|
#list_pending_invitation_resources(params = {}) ⇒ Types::ListPendingInvitationResourcesResponse
Lists the resources in a resource share that is shared with you but
for which the invitation is still PENDING. That means that you
haven't accepted or rejected the invitation and the invitation
hasn't expired.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
344 |
# File 'sig/client.rbs', line 344
def list_pending_invitation_resources: (
|
#list_permission_associations(params = {}) ⇒ Types::ListPermissionAssociationsResponse
Lists information about the managed permission and its associations to any resource shares that use this managed permission. This lets you see which resource shares use which versions of the specified managed permission.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
358 |
# File 'sig/client.rbs', line 358
def list_permission_associations: (
|
#list_permission_versions(params = {}) ⇒ Types::ListPermissionVersionsResponse
Lists the available versions of the specified RAM permission.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
376 |
# File 'sig/client.rbs', line 376
def list_permission_versions: (
|
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Retrieves a list of available RAM permissions that you can use for the supported resource types.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
389 |
# File 'sig/client.rbs', line 389
def list_permissions: (
|
#list_principals(params = {}) ⇒ Types::ListPrincipalsResponse
Lists the principals that you are sharing resources with or that are sharing resources with you.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
403 |
# File 'sig/client.rbs', line 403
def list_principals: (
|
#list_replace_permission_associations_work(params = {}) ⇒ Types::ListReplacePermissionAssociationsWorkResponse
Retrieves the current status of the asynchronous tasks performed by RAM when you perform the ReplacePermissionAssociationsWork operation.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
420 |
# File 'sig/client.rbs', line 420
def list_replace_permission_associations_work: (
|
#list_resource_share_permissions(params = {}) ⇒ Types::ListResourceSharePermissionsResponse
Lists the RAM permissions that are associated with a resource share.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
434 |
# File 'sig/client.rbs', line 434
def list_resource_share_permissions: (
|
#list_resource_types(params = {}) ⇒ Types::ListResourceTypesResponse
Lists the resource types that can be shared by RAM.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
447 |
# File 'sig/client.rbs', line 447
def list_resource_types: (
|
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Lists the resources that you added to a resource share or the resources that are shared with you.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
460 |
# File 'sig/client.rbs', line 460
def list_resources: (
|
#list_source_associations(params = {}) ⇒ Types::ListSourceAssociationsResponse
Lists source associations for resource shares. Source associations control which sources can be used with service principals in resource shares. This operation provides visibility into source associations for resource share owners.
You can filter the results by resource share Amazon Resource Name (ARN), source ID, source type, or association status. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
478 |
# File 'sig/client.rbs', line 478
def list_source_associations: (
|
#promote_permission_created_from_policy(params = {}) ⇒ Types::PromotePermissionCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM
automatically creates a resource share of
featureSet=CREATED_FROM_POLICY with a managed permission that has
the same IAM permissions as the original resource-based policy.
However, this type of managed permission is visible to only the
resource share owner, and the associated resource share can't be
modified by using RAM.
This operation creates a separate, fully manageable customer managed permission that has the same IAM permissions as the original resource-based policy. You can associate this customer managed permission to any resource shares.
Before you use PromoteResourceShareCreatedFromPolicy, you should first run this operation to ensure that you have an appropriate customer managed permission that can be associated with the promoted resource share.
CREATED_FROM_POLICY policy isn't deleted, and
resource shares using that original policy aren't automatically
updated.
-
You can't modify a
CREATED_FROM_POLICYresource share so you can't associate the new customer managed permission by usingReplacePermsissionAssociations. However, if you use PromoteResourceShareCreatedFromPolicy, that operation automatically associates the fully manageable customer managed permission to the newly promotedSTANDARDresource share. -
After you promote a resource share, if the original
CREATED_FROM_POLICYmanaged permission has no other associations to A resource share, then RAM automatically deletes it.
494 |
# File 'sig/client.rbs', line 494
def promote_permission_created_from_policy: (
|
#promote_resource_share_created_from_policy(params = {}) ⇒ Types::PromoteResourceShareCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM
automatically creates a resource share of
featureSet=CREATED_FROM_POLICY with a managed permission that has
the same IAM permissions as the original resource-based policy.
However, this type of managed permission is visible to only the
resource share owner, and the associated resource share can't be
modified by using RAM.
This operation promotes the resource share to a STANDARD resource
share that is fully manageable in RAM. When you promote a resource
share, you can then manage the resource share in RAM and it becomes
visible to all of the principals you shared it with.
Before you perform this operation, you should first run
PromotePermissionCreatedFromPolicyto ensure that you have an
appropriate customer managed permission that can be associated with
this resource share after its is promoted. If this operation can't
find a managed permission that exactly matches the existing
CREATED_FROM_POLICY permission, then this operation fails.
506 |
# File 'sig/client.rbs', line 506
def promote_resource_share_created_from_policy: (
|
#reject_resource_share_invitation(params = {}) ⇒ Types::RejectResourceShareInvitationResponse
Rejects an invitation to a resource share from another Amazon Web Services account.
517 |
# File 'sig/client.rbs', line 517
def reject_resource_share_invitation: (
|
#replace_permission_associations(params = {}) ⇒ Types::ReplacePermissionAssociationsResponse
Updates all resource shares that use a managed permission to a different managed permission. This operation always applies the default version of the target managed permission. You can optionally specify that the update applies to only resource shares that currently use a specified version. This enables you to update to the latest version, without changing the which managed permission is used.
You can use this operation to update all of your resource shares to
use the current default version of the permission by specifying the
same value for the fromPermissionArn and toPermissionArn
parameters.
You can use the optional fromPermissionVersion parameter to update
only those resources that use a specified version of the managed
permission to the new managed permission.
To successfully perform this operation, you must have permission to update the resource-based policy on all affected resource types.
529 |
# File 'sig/client.rbs', line 529
def replace_permission_associations: (
|
#set_default_permission_version(params = {}) ⇒ Types::SetDefaultPermissionVersionResponse
Designates the specified version number as the default version for the specified customer managed permission. New resource shares automatically use this new default permission. Existing resource shares continue to use their original permission version, but you can use ReplacePermissionAssociations to update them.
543 |
# File 'sig/client.rbs', line 543
def set_default_permission_version: (
|
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag keys and values to a resource share or managed permission. If you choose a resource share, the tags are attached to only the resource share, not to the resources that are in the resource share.
The tags on a managed permission are the same for all versions of the managed permission.
554 |
# File 'sig/client.rbs', line 554
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tag key and value pairs from the specified resource share or managed permission.
570 |
# File 'sig/client.rbs', line 570
def untag_resource: (
|
#update_resource_share(params = {}) ⇒ Types::UpdateResourceShareResponse
Modifies some of the properties of the specified resource share.
583 |
# File 'sig/client.rbs', line 583
def update_resource_share: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3589 3590 3591 |
# File 'lib/aws-sdk-ram/client.rb', line 3589 def waiter_names [] end |