Class: Aws::RAM::Types::AssociatedSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ram/types.rb

Overview

Information about a source association in a resource share. Source associations control which sources can be used with service principals.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time when the source association was created.



435
436
437
438
439
440
441
442
443
444
445
# File 'lib/aws-sdk-ram/types.rb', line 435

class AssociatedSource < Struct.new(
  :resource_share_arn,
  :source_id,
  :source_type,
  :status,
  :last_updated_time,
  :creation_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The date and time when the source association was last updated.



435
436
437
438
439
440
441
442
443
444
445
# File 'lib/aws-sdk-ram/types.rb', line 435

class AssociatedSource < Struct.new(
  :resource_share_arn,
  :source_id,
  :source_type,
  :status,
  :last_updated_time,
  :creation_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#resource_share_arnString

The Amazon Resource Name (ARN) of the resource share that contains the source association.



435
436
437
438
439
440
441
442
443
444
445
# File 'lib/aws-sdk-ram/types.rb', line 435

class AssociatedSource < Struct.new(
  :resource_share_arn,
  :source_id,
  :source_type,
  :status,
  :last_updated_time,
  :creation_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#source_idString

The identifier of the source. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.



435
436
437
438
439
440
441
442
443
444
445
# File 'lib/aws-sdk-ram/types.rb', line 435

class AssociatedSource < Struct.new(
  :resource_share_arn,
  :source_id,
  :source_type,
  :status,
  :last_updated_time,
  :creation_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The type of source.



435
436
437
438
439
440
441
442
443
444
445
# File 'lib/aws-sdk-ram/types.rb', line 435

class AssociatedSource < Struct.new(
  :resource_share_arn,
  :source_id,
  :source_type,
  :status,
  :last_updated_time,
  :creation_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the source association.



435
436
437
438
439
440
441
442
443
444
445
# File 'lib/aws-sdk-ram/types.rb', line 435

class AssociatedSource < Struct.new(
  :resource_share_arn,
  :source_id,
  :source_type,
  :status,
  :last_updated_time,
  :creation_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A message about the status of the source association.



435
436
437
438
439
440
441
442
443
444
445
# File 'lib/aws-sdk-ram/types.rb', line 435

class AssociatedSource < Struct.new(
  :resource_share_arn,
  :source_id,
  :source_type,
  :status,
  :last_updated_time,
  :creation_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end