Class: Aws::RAM::Types::DisassociateResourceShareRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::DisassociateResourceShareRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#principals ⇒ Array<String>
Specifies a list of one or more principals that no longer are to have access to the resources in this resource share.
-
#resource_arns ⇒ Array<String>
Specifies a list of [Amazon Resource Names (ARNs)] for one or more resources that you want to remove from the resource share.
-
#resource_share_arn ⇒ String
Specifies [Amazon Resource Name (ARN)] of the resource share that you want to remove resources or principals from.
-
#sources ⇒ Array<String>
Specifies source constraints (accounts, ARNs, organization IDs, or organization paths) to remove from the resource share.
Instance Attribute Details
#client_token ⇒ String
Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a [UUID type of value.].
If you don’t provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ‘ClientToken`, but with different parameters, the retry fails with an `IdempotentParameterMismatch` error.
1156 1157 1158 1159 1160 1161 1162 1163 1164 |
# File 'lib/aws-sdk-ram/types.rb', line 1156 class DisassociateResourceShareRequest < Struct.new( :resource_share_arn, :resource_arns, :principals, :client_token, :sources) SENSITIVE = [] include Aws::Structure end |
#principals ⇒ Array<String>
Specifies a list of one or more principals that no longer are to have access to the resources in this resource share.
You can include the following values:
-
An Amazon Web Services account ID, for example: ‘123456789012`
-
An [Amazon Resource Name (ARN)] of an organization in Organizations, for example: ‘organizations::123456789012:organization/o-exampleorgid`
-
An ARN of an organizational unit (OU) in Organizations, for example: ‘organizations::123456789012:ou/o-exampleorgid/ou-examplerootid-exampleouid123`
-
An ARN of an IAM role, for example: ‘iam::123456789012:role/rolename`
-
An ARN of an IAM user, for example: ‘iam::123456789012user/username`
-
A service principal name, for example: ‘service-id.amazonaws.com`
<note markdown=“1”> Not all resource types can be shared with IAM roles and users. For more information, see [Sharing with IAM roles and users] in the *Resource Access Manager User Guide*.
</note>
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html [2]: docs.aws.amazon.com/ram/latest/userguide/permissions.html#permissions-rbp-supported-resource-types
1156 1157 1158 1159 1160 1161 1162 1163 1164 |
# File 'lib/aws-sdk-ram/types.rb', line 1156 class DisassociateResourceShareRequest < Struct.new( :resource_share_arn, :resource_arns, :principals, :client_token, :sources) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
Specifies a list of [Amazon Resource Names (ARNs)] for one or more resources that you want to remove from the resource share. After the operation runs, these resources are no longer shared with principals associated with the resource share.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1156 1157 1158 1159 1160 1161 1162 1163 1164 |
# File 'lib/aws-sdk-ram/types.rb', line 1156 class DisassociateResourceShareRequest < Struct.new( :resource_share_arn, :resource_arns, :principals, :client_token, :sources) SENSITIVE = [] include Aws::Structure end |
#resource_share_arn ⇒ String
Specifies [Amazon Resource Name (ARN)] of the resource share that you want to remove resources or principals from.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1156 1157 1158 1159 1160 1161 1162 1163 1164 |
# File 'lib/aws-sdk-ram/types.rb', line 1156 class DisassociateResourceShareRequest < Struct.new( :resource_share_arn, :resource_arns, :principals, :client_token, :sources) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<String>
Specifies source constraints (accounts, ARNs, organization IDs, or organization paths) to remove from the resource share. This enables granular management of source constraints while maintaining service principal associations. At least one source must remain when service principals are present.
1156 1157 1158 1159 1160 1161 1162 1163 1164 |
# File 'lib/aws-sdk-ram/types.rb', line 1156 class DisassociateResourceShareRequest < Struct.new( :resource_share_arn, :resource_arns, :principals, :client_token, :sources) SENSITIVE = [] include Aws::Structure end |