Class: Aws::RAM::Types::GetResourcePoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::GetResourcePoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the total number of results that you want included on each page of the response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#principal ⇒ String
Specifies the principal.
-
#resource_arns ⇒ Array<String>
Specifies the [Amazon Resource Names (ARNs)] of the resources whose policies you want to retrieve.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the number you specify, the ‘NextToken` response element is returned with a value (not null). Include the specified value as the `NextToken` request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check `NextToken` after every operation to ensure that you receive all of the results.
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-ram/types.rb', line 1285 class GetResourcePoliciesRequest < Struct.new( :resource_arns, :principal, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a ‘NextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘NextToken` response to request the next page of results.
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-ram/types.rb', line 1285 class GetResourcePoliciesRequest < Struct.new( :resource_arns, :principal, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
Specifies the principal.
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-ram/types.rb', line 1285 class GetResourcePoliciesRequest < Struct.new( :resource_arns, :principal, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
Specifies the [Amazon Resource Names (ARNs)] of the resources whose policies you want to retrieve.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-ram/types.rb', line 1285 class GetResourcePoliciesRequest < Struct.new( :resource_arns, :principal, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |