Class: Aws::RAM::Types::GetResourceShareInvitationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::GetResourceShareInvitationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the total number of results that you want included on each page of the response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#resource_share_arns ⇒ Array<String>
Specifies that you want details about invitations only for the resource shares described by this list of [Amazon Resource Names (ARNs)].
-
#resource_share_invitation_arns ⇒ Array<String>
Specifies the [Amazon Resource Names (ARNs)] of the resource share invitations you want information about.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the number you specify, the ‘NextToken` response element is returned with a value (not null). Include the specified value as the `NextToken` request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check `NextToken` after every operation to ensure that you receive all of the results.
1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/aws-sdk-ram/types.rb', line 1466 class GetResourceShareInvitationsRequest < Struct.new( :resource_share_invitation_arns, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a ‘NextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘NextToken` response to request the next page of results.
1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/aws-sdk-ram/types.rb', line 1466 class GetResourceShareInvitationsRequest < Struct.new( :resource_share_invitation_arns, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_share_arns ⇒ Array<String>
Specifies that you want details about invitations only for the resource shares described by this list of [Amazon Resource Names (ARNs)]
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/aws-sdk-ram/types.rb', line 1466 class GetResourceShareInvitationsRequest < Struct.new( :resource_share_invitation_arns, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_share_invitation_arns ⇒ Array<String>
Specifies the [Amazon Resource Names (ARNs)] of the resource share invitations you want information about.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/aws-sdk-ram/types.rb', line 1466 class GetResourceShareInvitationsRequest < Struct.new( :resource_share_invitation_arns, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |