Class: Aws::RAM::Types::ListPendingInvitationResourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::ListPendingInvitationResourcesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If present, this value indicates that more output is available than is included in the current response.
-
#resources ⇒ Array<Types::Resource>
An array of objects that contain the information about the resources included the specified resource share.
Instance Attribute Details
#next_token ⇒ String
If present, this value indicates that more output is available than
is included in the current response. Use this value in the
NextToken request parameter in a subsequent call to the operation
to get the next part of the output. You should repeat this until the
NextToken response element comes back as null. This indicates
that this is the last page of results.
1791 1792 1793 1794 1795 1796 |
# File 'lib/aws-sdk-ram/types.rb', line 1791 class ListPendingInvitationResourcesResponse < Struct.new( :resources, :next_token) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::Resource>
An array of objects that contain the information about the resources included the specified resource share.
1791 1792 1793 1794 1795 1796 |
# File 'lib/aws-sdk-ram/types.rb', line 1791 class ListPendingInvitationResourcesResponse < Struct.new( :resources, :next_token) SENSITIVE = [] include Aws::Structure end |