Class: Aws::RAM::Types::ListPermissionAssociationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ram/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If present, this value indicates that more output is available than is included in the current response. Use this value in the NextToken request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the NextToken response element comes back as null. This indicates that this is the last page of results.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-ram/types.rb', line 1891

class ListPermissionAssociationsResponse < Struct.new(
  :permissions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsArray<Types::AssociatedPermission>

A structure with information about this customer managed permission.

Returns:



1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-ram/types.rb', line 1891

class ListPermissionAssociationsResponse < Struct.new(
  :permissions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end