Class: Aws::RAM::Types::ListPermissionVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ram/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If present, this value indicates that more output is available than is included in the current response. Use this value in the NextToken request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the NextToken response element comes back as null. This indicates that this is the last page of results.

Returns:

  • (String)


1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-ram/types.rb', line 1956

class ListPermissionVersionsResponse < Struct.new(
  :permissions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsArray<Types::ResourceSharePermissionSummary>

An array of objects that contain details for each of the available versions.



1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-ram/types.rb', line 1956

class ListPermissionVersionsResponse < Struct.new(
  :permissions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end