Class: Aws::RAM::Types::ListPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::ListPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the total number of results that you want included on each page of the response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#permission_type ⇒ String
Specifies that you want to list only permissions of this type:.
-
#resource_type ⇒ String
Specifies that you want to list only those permissions that apply to the specified resource type.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the total number of results that you want included on each
page of the response. If you do not include this parameter, it
defaults to a value that is specific to the operation. If additional
items exist beyond the number you specify, the NextToken response
element is returned with a value (not null). Include the specified
value as the NextToken request parameter in the next call to the
operation to get the next part of the results. Note that the service
might return fewer results than the maximum even when there are more
results available. You should check NextToken after every
operation to ensure that you receive all of the results.
2008 2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-ram/types.rb', line 2008 class ListPermissionsRequest < Struct.new( :resource_type, :next_token, :max_results, :permission_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid
only if you received a NextToken response in the previous request.
If you did, it indicates that more output is available. Set this
parameter to the value provided by the previous call's NextToken
response to request the next page of results.
2008 2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-ram/types.rb', line 2008 class ListPermissionsRequest < Struct.new( :resource_type, :next_token, :max_results, :permission_type) SENSITIVE = [] include Aws::Structure end |
#permission_type ⇒ String
Specifies that you want to list only permissions of this type:
-
AWS– returns only Amazon Web Services managed permissions. -
LOCAL– returns only customer managed permissions -
ALL– returns both Amazon Web Services managed permissions and customer managed permissions.
If you don't specify this parameter, the default is All.
2008 2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-ram/types.rb', line 2008 class ListPermissionsRequest < Struct.new( :resource_type, :next_token, :max_results, :permission_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Specifies that you want to list only those permissions that apply to the specified resource type. This parameter is not case sensitive.
For example, to list only permissions that apply to Amazon EC2
subnets, specify ec2:subnet. You can use the ListResourceTypes
operation to get the specific string required.
2008 2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-ram/types.rb', line 2008 class ListPermissionsRequest < Struct.new( :resource_type, :next_token, :max_results, :permission_type) SENSITIVE = [] include Aws::Structure end |