Class: Aws::RAM::Types::ListPrincipalsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::ListPrincipalsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the total number of results that you want included on each page of the response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#principals ⇒ Array<String>
Specifies that you want to list information for only the listed principals.
-
#resource_arn ⇒ String
Specifies that you want to list principal information for the resource share with the specified [Amazon Resource Name (ARN)][1].
-
#resource_owner ⇒ String
Specifies that you want to list information for only resource shares that match the following:.
-
#resource_share_arns ⇒ Array<String>
Specifies that you want to list information for only principals associated with the resource shares specified by a list the [Amazon Resource Names (ARNs)][1].
-
#resource_type ⇒ String
Specifies that you want to list information for only principals associated with resource shares that include the specified resource type.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the total number of results that you want included on each
page of the response. If you do not include this parameter, it
defaults to a value that is specific to the operation. If additional
items exist beyond the number you specify, the NextToken response
element is returned with a value (not null). Include the specified
value as the NextToken request parameter in the next call to the
operation to get the next part of the results. Note that the service
might return fewer results than the maximum even when there are more
results available. You should check NextToken after every
operation to ensure that you receive all of the results.
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-ram/types.rb', line 2136 class ListPrincipalsRequest < Struct.new( :resource_owner, :resource_arn, :principals, :resource_type, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid
only if you received a NextToken response in the previous request.
If you did, it indicates that more output is available. Set this
parameter to the value provided by the previous call's NextToken
response to request the next page of results.
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-ram/types.rb', line 2136 class ListPrincipalsRequest < Struct.new( :resource_owner, :resource_arn, :principals, :resource_type, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#principals ⇒ Array<String>
Specifies that you want to list information for only the listed principals.
You can include the following values:
-
An Amazon Web Services account ID, for example:
123456789012 -
An Amazon Resource Name (ARN) of an organization in Organizations, for example:
organizations::123456789012:organization/o-exampleorgid -
An ARN of an organizational unit (OU) in Organizations, for example:
organizations::123456789012:ou/o-exampleorgid/ou-examplerootid-exampleouid123 -
An ARN of an IAM role, for example:
iam::123456789012:role/rolename -
An ARN of an IAM user, for example:
iam::123456789012user/username -
A service principal name, for example:
service-id.amazonaws.com
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-ram/types.rb', line 2136 class ListPrincipalsRequest < Struct.new( :resource_owner, :resource_arn, :principals, :resource_type, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
Specifies that you want to list principal information for the resource share with the specified Amazon Resource Name (ARN).
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-ram/types.rb', line 2136 class ListPrincipalsRequest < Struct.new( :resource_owner, :resource_arn, :principals, :resource_type, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_owner ⇒ String
Specifies that you want to list information for only resource shares that match the following:
-
SELF– principals that your account is sharing resources with -
OTHER-ACCOUNTS– principals that are sharing resources with your account
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-ram/types.rb', line 2136 class ListPrincipalsRequest < Struct.new( :resource_owner, :resource_arn, :principals, :resource_type, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_share_arns ⇒ Array<String>
Specifies that you want to list information for only principals associated with the resource shares specified by a list the Amazon Resource Names (ARNs).
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-ram/types.rb', line 2136 class ListPrincipalsRequest < Struct.new( :resource_owner, :resource_arn, :principals, :resource_type, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Specifies that you want to list information for only principals associated with resource shares that include the specified resource type.
For a list of valid values, query the ListResourceTypes operation.
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-ram/types.rb', line 2136 class ListPrincipalsRequest < Struct.new( :resource_owner, :resource_arn, :principals, :resource_type, :resource_share_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |