Class: Aws::RAM::Types::ListResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::ListResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the total number of results that you want included on each page of the response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#principal ⇒ String
Specifies that you want to list only the resource shares that are associated with the specified principal.
-
#resource_arns ⇒ Array<String>
Specifies that you want to list only the resource shares that include resources with the specified [Amazon Resource Names (ARNs)][1].
-
#resource_owner ⇒ String
Specifies that you want to list only the resource shares that match the following:.
-
#resource_region_scope ⇒ String
Specifies that you want the results to include only resources that have the specified scope.
-
#resource_share_arns ⇒ Array<String>
Specifies that you want to list only resources in the resource shares identified by the specified [Amazon Resource Names (ARNs)][1].
-
#resource_type ⇒ String
Specifies that you want to list only the resource shares that include resources of the specified resource type.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the total number of results that you want included on each
page of the response. If you do not include this parameter, it
defaults to a value that is specific to the operation. If additional
items exist beyond the number you specify, the NextToken response
element is returned with a value (not null). Include the specified
value as the NextToken request parameter in the next call to the
operation to get the next part of the results. Note that the service
might return fewer results than the maximum even when there are more
results available. You should check NextToken after every
operation to ensure that you receive all of the results.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid
only if you received a NextToken response in the previous request.
If you did, it indicates that more output is available. Set this
parameter to the value provided by the previous call's NextToken
response to request the next page of results.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
Specifies that you want to list only the resource shares that are associated with the specified principal.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
Specifies that you want to list only the resource shares that include resources with the specified Amazon Resource Names (ARNs).
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |
#resource_owner ⇒ String
Specifies that you want to list only the resource shares that match the following:
-
SELF– resources that your account shares with other accounts -
OTHER-ACCOUNTS– resources that other accounts share with your account
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |
#resource_region_scope ⇒ String
Specifies that you want the results to include only resources that have the specified scope.
-
ALL– the results include both global and regional resources or resource types. -
GLOBAL– the results include only global resources or resource types. -
REGIONAL– the results include only regional resources or resource types.
The default value is ALL.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |
#resource_share_arns ⇒ Array<String>
Specifies that you want to list only resources in the resource shares identified by the specified Amazon Resource Names (ARNs).
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Specifies that you want to list only the resource shares that include resources of the specified resource type.
For valid values, query the ListResourceTypes operation.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-ram/types.rb', line 2451 class ListResourcesRequest < Struct.new( :resource_owner, :principal, :resource_type, :resource_arns, :resource_share_arns, :next_token, :max_results, :resource_region_scope) SENSITIVE = [] include Aws::Structure end |