Class: Aws::RAM::Types::ListSourceAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ram/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_statusString

The status of the source associations that you want to retrieve.

Returns:

  • (String)


2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
# File 'lib/aws-sdk-ram/types.rb', line 2518

class ListSourceAssociationsRequest < Struct.new(
  :resource_share_arns,
  :source_id,
  :source_type,
  :association_status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
# File 'lib/aws-sdk-ram/types.rb', line 2518

class ListSourceAssociationsRequest < Struct.new(
  :resource_share_arns,
  :source_id,
  :source_type,
  :association_status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token that indicates the next set of results to retrieve.

Returns:

  • (String)


2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
# File 'lib/aws-sdk-ram/types.rb', line 2518

class ListSourceAssociationsRequest < Struct.new(
  :resource_share_arns,
  :source_id,
  :source_type,
  :association_status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_share_arnsArray<String>

The Amazon Resource Names (ARNs) of the resource shares for which you want to retrieve source associations.

Returns:

  • (Array<String>)


2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
# File 'lib/aws-sdk-ram/types.rb', line 2518

class ListSourceAssociationsRequest < Struct.new(
  :resource_share_arns,
  :source_id,
  :source_type,
  :association_status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#source_idString

The identifier of the source for which you want to retrieve associations. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.

Returns:

  • (String)


2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
# File 'lib/aws-sdk-ram/types.rb', line 2518

class ListSourceAssociationsRequest < Struct.new(
  :resource_share_arns,
  :source_id,
  :source_type,
  :association_status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The type of source for which you want to retrieve associations.

Returns:

  • (String)


2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
# File 'lib/aws-sdk-ram/types.rb', line 2518

class ListSourceAssociationsRequest < Struct.new(
  :resource_share_arns,
  :source_id,
  :source_type,
  :association_status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end