Class: Aws::RAM::Types::ResourceShareAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ram/types.rb

Overview

Describes an association between a resource share and either a principal or a resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_entityString

The associated entity. This can be either of the following:

  • For a resource association, this is the Amazon Resource Name (ARN) of the resource.

  • For principal associations, this is one of the following:

  • The ID of an Amazon Web Services account

  • The Amazon Resource Name (ARN) of an organization in Organizations

  • The ARN of an organizational unit (OU) in Organizations

  • The ARN of an IAM role

  • The ARN of an IAM user



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#association_typeString

The type of entity included in this association.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The date and time when the association was created.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#externalBoolean

Indicates whether the principal belongs to the same organization in Organizations as the Amazon Web Services account that owns the resource share.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The date and time when the association was last updated.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#resource_share_arnString

The Amazon Resource Name (ARN) of the resource share.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#resource_share_nameString

The name of the resource share.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the association.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A message about the status of the association.



3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/aws-sdk-ram/types.rb', line 3283

class ResourceShareAssociation < Struct.new(
  :resource_share_arn,
  :resource_share_name,
  :associated_entity,
  :association_type,
  :status,
  :status_message,
  :creation_time,
  :last_updated_time,
  :external)
  SENSITIVE = []
  include Aws::Structure
end