Class: Aws::RAM::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RAM::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ram/client.rb
Overview
An API client for RAM. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::RAM::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_resource_share_invitation(params = {}) ⇒ Types::AcceptResourceShareInvitationResponse
Accepts an invitation to a resource share from another Amazon Web Services account.
-
#associate_resource_share(params = {}) ⇒ Types::AssociateResourceShareResponse
Adds the specified list of principals, resources, and source constraints to a resource share.
-
#associate_resource_share_permission(params = {}) ⇒ Types::AssociateResourceSharePermissionResponse
Adds or replaces the RAM permission for a resource type included in a resource share.
-
#create_permission(params = {}) ⇒ Types::CreatePermissionResponse
Creates a customer managed permission for a specified resource type that you can attach to resource shares.
-
#create_permission_version(params = {}) ⇒ Types::CreatePermissionVersionResponse
Creates a new version of the specified customer managed permission.
-
#create_resource_share(params = {}) ⇒ Types::CreateResourceShareResponse
Creates a resource share.
-
#delete_permission(params = {}) ⇒ Types::DeletePermissionResponse
Deletes the specified customer managed permission in the Amazon Web Services Region in which you call this operation.
-
#delete_permission_version(params = {}) ⇒ Types::DeletePermissionVersionResponse
Deletes one version of a customer managed permission.
-
#delete_resource_share(params = {}) ⇒ Types::DeleteResourceShareResponse
Deletes the specified resource share.
-
#disassociate_resource_share(params = {}) ⇒ Types::DisassociateResourceShareResponse
Removes the specified principals, resources, or source constraints from participating in the specified resource share.
-
#disassociate_resource_share_permission(params = {}) ⇒ Types::DisassociateResourceSharePermissionResponse
Removes a managed permission from a resource share.
-
#enable_sharing_with_aws_organization(params = {}) ⇒ Types::EnableSharingWithAwsOrganizationResponse
Enables resource sharing within your organization in Organizations.
-
#get_permission(params = {}) ⇒ Types::GetPermissionResponse
Retrieves the contents of a managed permission in JSON format.
-
#get_resource_policies(params = {}) ⇒ Types::GetResourcePoliciesResponse
Retrieves the resource policies for the specified resources that you own and have shared.
-
#get_resource_share_associations(params = {}) ⇒ Types::GetResourceShareAssociationsResponse
Retrieves the lists of resources and principals that associated for resource shares that you own.
-
#get_resource_share_invitations(params = {}) ⇒ Types::GetResourceShareInvitationsResponse
Retrieves details about invitations that you have received for resource shares.
-
#get_resource_shares(params = {}) ⇒ Types::GetResourceSharesResponse
Retrieves details about the resource shares that you own or that are shared with you.
-
#list_pending_invitation_resources(params = {}) ⇒ Types::ListPendingInvitationResourcesResponse
Lists the resources in a resource share that is shared with you but for which the invitation is still ‘PENDING`.
-
#list_permission_associations(params = {}) ⇒ Types::ListPermissionAssociationsResponse
Lists information about the managed permission and its associations to any resource shares that use this managed permission.
-
#list_permission_versions(params = {}) ⇒ Types::ListPermissionVersionsResponse
Lists the available versions of the specified RAM permission.
-
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Retrieves a list of available RAM permissions that you can use for the supported resource types.
-
#list_principals(params = {}) ⇒ Types::ListPrincipalsResponse
Lists the principals that you are sharing resources with or that are sharing resources with you.
-
#list_replace_permission_associations_work(params = {}) ⇒ Types::ListReplacePermissionAssociationsWorkResponse
Retrieves the current status of the asynchronous tasks performed by RAM when you perform the ReplacePermissionAssociationsWork operation.
-
#list_resource_share_permissions(params = {}) ⇒ Types::ListResourceSharePermissionsResponse
Lists the RAM permissions that are associated with a resource share.
-
#list_resource_types(params = {}) ⇒ Types::ListResourceTypesResponse
Lists the resource types that can be shared by RAM.
-
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Lists the resources that you added to a resource share or the resources that are shared with you.
-
#list_source_associations(params = {}) ⇒ Types::ListSourceAssociationsResponse
Lists source associations for resource shares.
-
#promote_permission_created_from_policy(params = {}) ⇒ Types::PromotePermissionCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM automatically creates a resource share of ‘featureSet`=`CREATED_FROM_POLICY` with a managed permission that has the same IAM permissions as the original resource-based policy.
-
#promote_resource_share_created_from_policy(params = {}) ⇒ Types::PromoteResourceShareCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM automatically creates a resource share of ‘featureSet`=`CREATED_FROM_POLICY` with a managed permission that has the same IAM permissions as the original resource-based policy.
-
#reject_resource_share_invitation(params = {}) ⇒ Types::RejectResourceShareInvitationResponse
Rejects an invitation to a resource share from another Amazon Web Services account.
-
#replace_permission_associations(params = {}) ⇒ Types::ReplacePermissionAssociationsResponse
Updates all resource shares that use a managed permission to a different managed permission.
-
#set_default_permission_version(params = {}) ⇒ Types::SetDefaultPermissionVersionResponse
Designates the specified version number as the default version for the specified customer managed permission.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag keys and values to a resource share or managed permission.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tag key and value pairs from the specified resource share or managed permission.
-
#update_resource_share(params = {}) ⇒ Types::UpdateResourceShareResponse
Modifies some of the properties of the specified resource share.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ram/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3596 3597 3598 |
# File 'lib/aws-sdk-ram/client.rb', line 3596 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3599 3600 3601 |
# File 'lib/aws-sdk-ram/client.rb', line 3599 def errors_module Errors end |
Instance Method Details
#accept_resource_share_invitation(params = {}) ⇒ Types::AcceptResourceShareInvitationResponse
Accepts an invitation to a resource share from another Amazon Web Services account. After you accept the invitation, the resources included in the resource share are available to interact with in the relevant Amazon Web Services Management Consoles and tools.
547 548 549 550 |
# File 'lib/aws-sdk-ram/client.rb', line 547 def accept_resource_share_invitation(params = {}, = {}) req = build_request(:accept_resource_share_invitation, params) req.send_request() end |
#associate_resource_share(params = {}) ⇒ Types::AssociateResourceShareResponse
Adds the specified list of principals, resources, and source constraints to a resource share. Principals that already have access to this resource share immediately receive access to the added resources. Newly added principals immediately receive access to the resources shared in this resource share.
673 674 675 676 |
# File 'lib/aws-sdk-ram/client.rb', line 673 def associate_resource_share(params = {}, = {}) req = build_request(:associate_resource_share, params) req.send_request() end |
#associate_resource_share_permission(params = {}) ⇒ Types::AssociateResourceSharePermissionResponse
Adds or replaces the RAM permission for a resource type included in a resource share. You can have exactly one permission associated with each resource type in the resource share. You can add a new RAM permission only if there are currently no resources of that resource type currently in the resource share.
775 776 777 778 |
# File 'lib/aws-sdk-ram/client.rb', line 775 def (params = {}, = {}) req = build_request(:associate_resource_share_permission, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 |
# File 'lib/aws-sdk-ram/client.rb', line 3569 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RAM') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ram' context[:gem_version] = '1.89.0' Seahorse::Client::Request.new(handlers, context) end |
#create_permission(params = {}) ⇒ Types::CreatePermissionResponse
Creates a customer managed permission for a specified resource type that you can attach to resource shares. It is created in the Amazon Web Services Region in which you call the operation.
895 896 897 898 |
# File 'lib/aws-sdk-ram/client.rb', line 895 def (params = {}, = {}) req = build_request(:create_permission, params) req.send_request() end |
#create_permission_version(params = {}) ⇒ Types::CreatePermissionVersionResponse
Creates a new version of the specified customer managed permission. The new version is automatically set as the default version of the customer managed permission. New resource shares automatically use the default permission. Existing resource shares continue to use their original permission versions, but you can use ReplacePermissionAssociations to update them.
If the specified customer managed permission already has the maximum of 5 versions, then you must delete one of the existing versions before you can create a new one.
1005 1006 1007 1008 |
# File 'lib/aws-sdk-ram/client.rb', line 1005 def (params = {}, = {}) req = build_request(:create_permission_version, params) req.send_request() end |
#create_resource_share(params = {}) ⇒ Types::CreateResourceShareResponse
Creates a resource share. You can provide a list of the [Amazon Resource Names (ARNs)] for the resources that you want to share, a list of principals you want to share the resources with, the permissions to grant those principals, and optionally source constraints to enhance security for service principal sharing.
<note markdown=“1”> Sharing a resource makes it available for use by principals outside of the Amazon Web Services account that created the resource. Sharing doesn’t change any permissions or quotas that apply to the resource in the account that created it.
</note>
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1169 1170 1171 1172 |
# File 'lib/aws-sdk-ram/client.rb', line 1169 def create_resource_share(params = {}, = {}) req = build_request(:create_resource_share, params) req.send_request() end |
#delete_permission(params = {}) ⇒ Types::DeletePermissionResponse
Deletes the specified customer managed permission in the Amazon Web Services Region in which you call this operation. You can delete a customer managed permission only if it isn’t attached to any resource share. The operation deletes all versions associated with the customer managed permission.
1230 1231 1232 1233 |
# File 'lib/aws-sdk-ram/client.rb', line 1230 def (params = {}, = {}) req = build_request(:delete_permission, params) req.send_request() end |
#delete_permission_version(params = {}) ⇒ Types::DeletePermissionVersionResponse
Deletes one version of a customer managed permission. The version you specify must not be attached to any resource share and must not be the default version for the permission.
If a customer managed permission has the maximum of 5 versions, then you must delete at least one version before you can create another.
1310 1311 1312 1313 |
# File 'lib/aws-sdk-ram/client.rb', line 1310 def (params = {}, = {}) req = build_request(:delete_permission_version, params) req.send_request() end |
#delete_resource_share(params = {}) ⇒ Types::DeleteResourceShareResponse
Deletes the specified resource share.
This doesn’t delete any of the resources that were associated with the resource share; it only stops the sharing of those resources through this resource share.
1369 1370 1371 1372 |
# File 'lib/aws-sdk-ram/client.rb', line 1369 def delete_resource_share(params = {}, = {}) req = build_request(:delete_resource_share, params) req.send_request() end |
#disassociate_resource_share(params = {}) ⇒ Types::DisassociateResourceShareResponse
Removes the specified principals, resources, or source constraints from participating in the specified resource share.
1487 1488 1489 1490 |
# File 'lib/aws-sdk-ram/client.rb', line 1487 def disassociate_resource_share(params = {}, = {}) req = build_request(:disassociate_resource_share, params) req.send_request() end |
#disassociate_resource_share_permission(params = {}) ⇒ Types::DisassociateResourceSharePermissionResponse
Removes a managed permission from a resource share. Permission changes take effect immediately. You can remove a managed permission from a resource share only if there are currently no resources of the relevant resource type currently attached to the resource share.
1555 1556 1557 1558 |
# File 'lib/aws-sdk-ram/client.rb', line 1555 def (params = {}, = {}) req = build_request(:disassociate_resource_share_permission, params) req.send_request() end |
#enable_sharing_with_aws_organization(params = {}) ⇒ Types::EnableSharingWithAwsOrganizationResponse
Enables resource sharing within your organization in Organizations. This operation creates a service-linked role called ‘AWSServiceRoleForResourceAccessManager` that has the IAM managed policy named AWSResourceAccessManagerServiceRolePolicy attached. This role permits RAM to retrieve information about the organization and its structure. This lets you share resources with all of the accounts in the calling account’s organization by specifying the organization ID, or all of the accounts in an organizational unit (OU) by specifying the OU ID. Until you enable sharing within the organization, you can specify only individual Amazon Web Services accounts, or for supported resource types, IAM roles and users.
You must call this operation from an IAM role or user in the organization’s management account.
1587 1588 1589 1590 |
# File 'lib/aws-sdk-ram/client.rb', line 1587 def enable_sharing_with_aws_organization(params = {}, = {}) req = build_request(:enable_sharing_with_aws_organization, params) req.send_request() end |
#get_permission(params = {}) ⇒ Types::GetPermissionResponse
Retrieves the contents of a managed permission in JSON format.
1646 1647 1648 1649 |
# File 'lib/aws-sdk-ram/client.rb', line 1646 def (params = {}, = {}) req = build_request(:get_permission, params) req.send_request() end |
#get_resource_policies(params = {}) ⇒ Types::GetResourcePoliciesResponse
Retrieves the resource policies for the specified resources that you own and have shared.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1718 1719 1720 1721 |
# File 'lib/aws-sdk-ram/client.rb', line 1718 def get_resource_policies(params = {}, = {}) req = build_request(:get_resource_policies, params) req.send_request() end |
#get_resource_share_associations(params = {}) ⇒ Types::GetResourceShareAssociationsResponse
Retrieves the lists of resources and principals that associated for resource shares that you own.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1835 1836 1837 1838 |
# File 'lib/aws-sdk-ram/client.rb', line 1835 def get_resource_share_associations(params = {}, = {}) req = build_request(:get_resource_share_associations, params) req.send_request() end |
#get_resource_share_invitations(params = {}) ⇒ Types::GetResourceShareInvitationsResponse
Retrieves details about invitations that you have received for resource shares.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1930 1931 1932 1933 |
# File 'lib/aws-sdk-ram/client.rb', line 1930 def get_resource_share_invitations(params = {}, = {}) req = build_request(:get_resource_share_invitations, params) req.send_request() end |
#get_resource_shares(params = {}) ⇒ Types::GetResourceSharesResponse
Retrieves details about the resource shares that you own or that are shared with you.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2056 2057 2058 2059 |
# File 'lib/aws-sdk-ram/client.rb', line 2056 def get_resource_shares(params = {}, = {}) req = build_request(:get_resource_shares, params) req.send_request() end |
#list_pending_invitation_resources(params = {}) ⇒ Types::ListPendingInvitationResourcesResponse
Lists the resources in a resource share that is shared with you but for which the invitation is still ‘PENDING`. That means that you haven’t accepted or rejected the invitation and the invitation hasn’t expired.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2150 2151 2152 2153 |
# File 'lib/aws-sdk-ram/client.rb', line 2150 def list_pending_invitation_resources(params = {}, = {}) req = build_request(:list_pending_invitation_resources, params) req.send_request() end |
#list_permission_associations(params = {}) ⇒ Types::ListPermissionAssociationsResponse
Lists information about the managed permission and its associations to any resource shares that use this managed permission. This lets you see which resource shares use which versions of the specified managed permission.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2259 2260 2261 2262 |
# File 'lib/aws-sdk-ram/client.rb', line 2259 def (params = {}, = {}) req = build_request(:list_permission_associations, params) req.send_request() end |
#list_permission_versions(params = {}) ⇒ Types::ListPermissionVersionsResponse
Lists the available versions of the specified RAM permission.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2341 2342 2343 2344 |
# File 'lib/aws-sdk-ram/client.rb', line 2341 def (params = {}, = {}) req = build_request(:list_permission_versions, params) req.send_request() end |
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Retrieves a list of available RAM permissions that you can use for the supported resource types.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2435 2436 2437 2438 |
# File 'lib/aws-sdk-ram/client.rb', line 2435 def (params = {}, = {}) req = build_request(:list_permissions, params) req.send_request() end |
#list_principals(params = {}) ⇒ Types::ListPrincipalsResponse
Lists the principals that you are sharing resources with or that are sharing resources with you.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2570 2571 2572 2573 |
# File 'lib/aws-sdk-ram/client.rb', line 2570 def list_principals(params = {}, = {}) req = build_request(:list_principals, params) req.send_request() end |
#list_replace_permission_associations_work(params = {}) ⇒ Types::ListReplacePermissionAssociationsWorkResponse
Retrieves the current status of the asynchronous tasks performed by RAM when you perform the ReplacePermissionAssociationsWork operation.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2648 2649 2650 2651 |
# File 'lib/aws-sdk-ram/client.rb', line 2648 def (params = {}, = {}) req = build_request(:list_replace_permission_associations_work, params) req.send_request() end |
#list_resource_share_permissions(params = {}) ⇒ Types::ListResourceSharePermissionsResponse
Lists the RAM permissions that are associated with a resource share.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2728 2729 2730 2731 |
# File 'lib/aws-sdk-ram/client.rb', line 2728 def (params = {}, = {}) req = build_request(:list_resource_share_permissions, params) req.send_request() end |
#list_resource_types(params = {}) ⇒ Types::ListResourceTypesResponse
Lists the resource types that can be shared by RAM.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2796 2797 2798 2799 |
# File 'lib/aws-sdk-ram/client.rb', line 2796 def list_resource_types(params = {}, = {}) req = build_request(:list_resource_types, params) req.send_request() end |
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Lists the resources that you added to a resource share or the resources that are shared with you.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2920 2921 2922 2923 |
# File 'lib/aws-sdk-ram/client.rb', line 2920 def list_resources(params = {}, = {}) req = build_request(:list_resources, params) req.send_request() end |
#list_source_associations(params = {}) ⇒ Types::ListSourceAssociationsResponse
Lists source associations for resource shares. Source associations control which sources can be used with service principals in resource shares. This operation provides visibility into source associations for resource share owners.
You can filter the results by resource share Amazon Resource Name (ARN), source ID, source type, or association status. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2993 2994 2995 2996 |
# File 'lib/aws-sdk-ram/client.rb', line 2993 def list_source_associations(params = {}, = {}) req = build_request(:list_source_associations, params) req.send_request() end |
#promote_permission_created_from_policy(params = {}) ⇒ Types::PromotePermissionCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM automatically creates a resource share of ‘featureSet`=`CREATED_FROM_POLICY` with a managed permission that has the same IAM permissions as the original resource-based policy. However, this type of managed permission is visible to only the resource share owner, and the associated resource share can’t be modified by using RAM.
This operation creates a separate, fully manageable customer managed permission that has the same IAM permissions as the original resource-based policy. You can associate this customer managed permission to any resource shares.
Before you use PromoteResourceShareCreatedFromPolicy, you should first run this operation to ensure that you have an appropriate customer managed permission that can be associated with the promoted resource share.
<note markdown=“1”> * The original ‘CREATED_FROM_POLICY` policy isn’t deleted, and
resource shares using that original policy aren't automatically
updated.
-
You can’t modify a ‘CREATED_FROM_POLICY` resource share so you can’t associate the new customer managed permission by using ‘ReplacePermsissionAssociations`. However, if you use PromoteResourceShareCreatedFromPolicy, that operation automatically associates the fully manageable customer managed permission to the newly promoted `STANDARD` resource share.
-
After you promote a resource share, if the original ‘CREATED_FROM_POLICY` managed permission has no other associations to A resource share, then RAM automatically deletes it.
</note>
3100 3101 3102 3103 |
# File 'lib/aws-sdk-ram/client.rb', line 3100 def (params = {}, = {}) req = build_request(:promote_permission_created_from_policy, params) req.send_request() end |
#promote_resource_share_created_from_policy(params = {}) ⇒ Types::PromoteResourceShareCreatedFromPolicyResponse
When you attach a resource-based policy to a resource, RAM automatically creates a resource share of ‘featureSet`=`CREATED_FROM_POLICY` with a managed permission that has the same IAM permissions as the original resource-based policy. However, this type of managed permission is visible to only the resource share owner, and the associated resource share can’t be modified by using RAM.
This operation promotes the resource share to a ‘STANDARD` resource share that is fully manageable in RAM. When you promote a resource share, you can then manage the resource share in RAM and it becomes visible to all of the principals you shared it with.
Before you perform this operation, you should first run PromotePermissionCreatedFromPolicyto ensure that you have an appropriate customer managed permission that can be associated with this resource share after its is promoted. If this operation can’t find a managed permission that exactly matches the existing ‘CREATED_FROM_POLICY` permission, then this operation fails.
3151 3152 3153 3154 |
# File 'lib/aws-sdk-ram/client.rb', line 3151 def promote_resource_share_created_from_policy(params = {}, = {}) req = build_request(:promote_resource_share_created_from_policy, params) req.send_request() end |
#reject_resource_share_invitation(params = {}) ⇒ Types::RejectResourceShareInvitationResponse
Rejects an invitation to a resource share from another Amazon Web Services account.
3224 3225 3226 3227 |
# File 'lib/aws-sdk-ram/client.rb', line 3224 def reject_resource_share_invitation(params = {}, = {}) req = build_request(:reject_resource_share_invitation, params) req.send_request() end |
#replace_permission_associations(params = {}) ⇒ Types::ReplacePermissionAssociationsResponse
Updates all resource shares that use a managed permission to a different managed permission. This operation always applies the default version of the target managed permission. You can optionally specify that the update applies to only resource shares that currently use a specified version. This enables you to update to the latest version, without changing the which managed permission is used.
You can use this operation to update all of your resource shares to use the current default version of the permission by specifying the same value for the ‘fromPermissionArn` and `toPermissionArn` parameters.
You can use the optional ‘fromPermissionVersion` parameter to update only those resources that use a specified version of the managed permission to the new managed permission.
To successfully perform this operation, you must have permission to update the resource-based policy on all affected resource types.
3319 3320 3321 3322 |
# File 'lib/aws-sdk-ram/client.rb', line 3319 def (params = {}, = {}) req = build_request(:replace_permission_associations, params) req.send_request() end |
#set_default_permission_version(params = {}) ⇒ Types::SetDefaultPermissionVersionResponse
Designates the specified version number as the default version for the specified customer managed permission. New resource shares automatically use this new default permission. Existing resource shares continue to use their original permission version, but you can use ReplacePermissionAssociations to update them.
3384 3385 3386 3387 |
# File 'lib/aws-sdk-ram/client.rb', line 3384 def (params = {}, = {}) req = build_request(:set_default_permission_version, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag keys and values to a resource share or managed permission. If you choose a resource share, the tags are attached to only the resource share, not to the resources that are in the resource share.
The tags on a managed permission are the same for all versions of the managed permission.
3439 3440 3441 3442 |
# File 'lib/aws-sdk-ram/client.rb', line 3439 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tag key and value pairs from the specified resource share or managed permission.
3483 3484 3485 3486 |
# File 'lib/aws-sdk-ram/client.rb', line 3483 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_resource_share(params = {}) ⇒ Types::UpdateResourceShareResponse
Modifies some of the properties of the specified resource share.
3560 3561 3562 3563 |
# File 'lib/aws-sdk-ram/client.rb', line 3560 def update_resource_share(params = {}, = {}) req = build_request(:update_resource_share, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3589 3590 3591 |
# File 'lib/aws-sdk-ram/client.rb', line 3589 def waiter_names [] end |