Class: Aws::RAM::Types::ListPermissionAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::ListPermissionAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If present, this value indicates that more output is available than is included in the current response.
-
#permissions ⇒ Array<Types::AssociatedPermission>
A structure with information about this customer managed permission.
Instance Attribute Details
#next_token ⇒ String
If present, this value indicates that more output is available than
is included in the current response. Use this value in the
NextToken request parameter in a subsequent call to the operation
to get the next part of the output. You should repeat this until the
NextToken response element comes back as null. This indicates
that this is the last page of results.
1891 1892 1893 1894 1895 1896 |
# File 'lib/aws-sdk-ram/types.rb', line 1891 class ListPermissionAssociationsResponse < Struct.new( :permissions, :next_token) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::AssociatedPermission>
A structure with information about this customer managed permission.
1891 1892 1893 1894 1895 1896 |
# File 'lib/aws-sdk-ram/types.rb', line 1891 class ListPermissionAssociationsResponse < Struct.new( :permissions, :next_token) SENSITIVE = [] include Aws::Structure end |