Class: Aws::RAM::Types::ListSourceAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::ListSourceAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_status ⇒ String
The status of the source associations that you want to retrieve.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The pagination token that indicates the next set of results to retrieve.
-
#resource_share_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the resource shares for which you want to retrieve source associations.
-
#source_id ⇒ String
The identifier of the source for which you want to retrieve associations.
-
#source_type ⇒ String
The type of source for which you want to retrieve associations.
Instance Attribute Details
#association_status ⇒ String
The status of the source associations that you want to retrieve.
2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 |
# File 'lib/aws-sdk-ram/types.rb', line 2518 class ListSourceAssociationsRequest < Struct.new( :resource_share_arns, :source_id, :source_type, :association_status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 |
# File 'lib/aws-sdk-ram/types.rb', line 2518 class ListSourceAssociationsRequest < Struct.new( :resource_share_arns, :source_id, :source_type, :association_status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that indicates the next set of results to retrieve.
2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 |
# File 'lib/aws-sdk-ram/types.rb', line 2518 class ListSourceAssociationsRequest < Struct.new( :resource_share_arns, :source_id, :source_type, :association_status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_share_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the resource shares for which you want to retrieve source associations.
2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 |
# File 'lib/aws-sdk-ram/types.rb', line 2518 class ListSourceAssociationsRequest < Struct.new( :resource_share_arns, :source_id, :source_type, :association_status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#source_id ⇒ String
The identifier of the source for which you want to retrieve associations. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.
2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 |
# File 'lib/aws-sdk-ram/types.rb', line 2518 class ListSourceAssociationsRequest < Struct.new( :resource_share_arns, :source_id, :source_type, :association_status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of source for which you want to retrieve associations.
2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 |
# File 'lib/aws-sdk-ram/types.rb', line 2518 class ListSourceAssociationsRequest < Struct.new( :resource_share_arns, :source_id, :source_type, :association_status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |