Class: Aws::RAM::Types::ReplacePermissionAssociationsWork
- Inherits:
-
Struct
- Object
- Struct
- Aws::RAM::Types::ReplacePermissionAssociationsWork
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ram/types.rb
Overview
A structure that represents the background work that RAM performs when you invoke the ReplacePermissionAssociations operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time when this asynchronous background task was created.
-
#from_permission_arn ⇒ String
The [Amazon Resource Name (ARN)] of the managed permission that this background task is replacing.
-
#from_permission_version ⇒ String
The version of the managed permission that this background task is replacing.
-
#id ⇒ String
The unique identifier for the background task associated with one ReplacePermissionAssociations request.
-
#last_updated_time ⇒ Time
The date and time when the status of this background task was last updated.
-
#status ⇒ String
Specifies the current status of the background tasks for the specified ID.
-
#status_message ⇒ String
Specifies the reason for a ‘FAILED` status.
-
#to_permission_arn ⇒ String
The ARN of the managed permission that this background task is associating with the resource shares in place of the managed permission and version specified in ‘fromPermissionArn` and `fromPermissionVersion`.
-
#to_permission_version ⇒ String
The version of the managed permission that this background task is associating with the resource shares.
Instance Attribute Details
#creation_time ⇒ Time
The date and time when this asynchronous background task was created.
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#from_permission_arn ⇒ String
The [Amazon Resource Name (ARN)] of the managed permission that this background task is replacing.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#from_permission_version ⇒ String
The version of the managed permission that this background task is replacing.
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the background task associated with one ReplacePermissionAssociations request.
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The date and time when the status of this background task was last updated.
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Specifies the current status of the background tasks for the specified ID. The output is one of the following strings:
-
‘IN_PROGRESS`
-
‘COMPLETED`
-
‘FAILED`
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Specifies the reason for a ‘FAILED` status. This field is present only when there `status` is `FAILED`.
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#to_permission_arn ⇒ String
The ARN of the managed permission that this background task is associating with the resource shares in place of the managed permission and version specified in ‘fromPermissionArn` and `fromPermissionVersion`.
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#to_permission_version ⇒ String
The version of the managed permission that this background task is associating with the resource shares. This is always the version that is currently the default for this managed permission.
3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/aws-sdk-ram/types.rb', line 3005 class ReplacePermissionAssociationsWork < Struct.new( :id, :from_permission_arn, :from_permission_version, :to_permission_arn, :to_permission_version, :status, :status_message, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |